autowisp.astrometry.astrometry_net_client module — AutoWISP documentation

# autowisp.astrometry.astrometry_net_client module

## Class Inheritance Diagram

class autowisp.astrometry.astrometry_net_client.Client(apiurl='https://nova.astrometry.net/api/')

  Bases: `object`

  annotate_data(job_id)
    Parameters:

      job_id – id of job

    Returns:

      return data for annotations

  default_url = 'https://nova.astrometry.net/api/'
  galex_plot(outfn, wcsfn, wcsext=0)
  get_url(service)
  job_status(job_id, justdict=False)
  jobs_by_tag(tag, exact)
  login(apikey)
  myjobs()
  overlay_plot(service, outfn, wcsfn, wcsext=0)
  sdss_plot(outfn, wcsfn, wcsext=0)
  send_request(service, args={}, file_args=None)

    service: string args: dict

  sub_status(sub_id, justdict=False)
  submission_images(subid)
  upload(fn=None, **kwargs)
  url_upload(url, **kwargs)

exception autowisp.astrometry.astrometry_net_client.MalformedResponse

  Bases: `Exception`

exception autowisp.astrometry.astrometry_net_client.RequestError

  Bases: `Exception`

autowisp.astrometry.astrometry_net_client.json2python(data)